@@ -186,7 +186,7 @@ def parser():
                         people_links = parser_people_links(direct_link)
                         i=4
                     except:
-                        if i == 2 and (direct_link.find('perm') != -1 or direct_link.find('orenburg') != -1):
+                        if i == 2 and (direct_link.find('perm') == -1 or direct_link.find('orenburg') == -1):
                             return [{'code': 1, 'script': os.path.basename(__file__)}]
                         people_links = None
                         i+=1
